ActionType enum
Actions that can be performed on the WidgetTester
- Inheritance
- Available extensions
Values
- press → const ActionType
- enterText → const ActionType
- pumpAndSettle → const ActionType
- futureAwait → const ActionType
- customAction → const ActionType
- pump → const ActionType
- drag → const ActionType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toValue → String
-
Available on ActionType, provided by the ValueOnActionType extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ActionType> - A constant List of the values in this enum, in order of their declaration.