customAction property
Needed when TestActionType == CustomAction
Fails the test if this condition is not satisfied.
Implementation
final Function? customAction;
Needed when TestActionType == CustomAction
Fails the test if this condition is not satisfied.
final Function? customAction;