tester property
dynamic
get
tester
If the WidgetTester is set will be returned, otherwise will get null
Implementation
dynamic get tester => _tester;
If the WidgetTester is set will be returned, otherwise will get null
dynamic get tester => _tester;